@@ -12,5 +12,8 @@ class DumbPushDataHandler(object):
     def delete(self, database, table, data):
         self.callback_handle(PUSH_ACTION_DELETE, database, table, data)
 
+    def handle_custom(self, database, table, data, action):
+        self.callback_handle(action, database, table, data)
+
     def callback_handle(self, action, database, table, data):
         pass
