@@ -30,6 +30,12 @@ class SensePushManager(object):
             return "select * from {}".format(table)
         return "select * from {0} limit {1},{2}".format(table, offset, limit)
 
+    def push_sync_done(self, job_name):
+        message = build_sync_cmd_push_message(job_name)
+        handler = PushDataHandler(database=message['db'], table=message['table'], queue_configs=self.queue_configs)
+        handler.insert_data(message)
+        sd.log_info("done push_sync_done {}".format(message))
+
     def _build_config(self, label, config, keys):
         if not label:
             return config
