@@ -1,6 +1,7 @@
 import sense_core as sd
 import logging
-from sense_push.common import PUSH_ACTION_UPDATE
+import datetime
+from sense_push.common import PUSH_ACTION_UPDATE, PUSH_ACTION_INSERT
 
 
 def init_config(module='sense_push', module_name=''):
@@ -20,3 +21,12 @@ def build_push_message(action, database, table, data):
         table=table,
         data=data,
     )
+
+
+def build_sync_cmd_push_message(job_name):
+    data = {
+        "id": job_name,
+        "state": 0,
+        "create_time": str(datetime.datetime.now()),
+    }
+    return build_push_message(PUSH_ACTION_INSERT, "sense_push", "sync_cmd", data)
